<?php

// define database connection
  define('DB_SERVER', '[[softdbhost]]'); // eg, localhost - should not be empty for productive servers
  define('DB_SERVER_USERNAME', '[[softdbuser]]');
  define('DB_SERVER_PASSWORD', '[[softdbpass]]');
  define('DB_SERVER_PORT', '');		
  define('DB_DATABASE', '[[softdb]]');  	  
  